@@ -7,7 +7,7 @@ from django.core.exceptions import ObjectDoesNotExist, MultipleObjectsReturned
 from sso_server.models import Token
 from sso_server.utils import generate_random, time_slice
 
-from basics.models import User, Student
+from basics.models import User
 
 
 class TokenService(object):
@@ -80,7 +80,7 @@ class TokenService(object):
 		if token and isinstance(token, Token):
 			if token.user.is_active:
 				groups = [group.name for group in token.user.groups.all()]
-				username = str(token.user)
+				username = token.user.username
 				user_id = token.user_id
 				is_active = token.user.is_active
 				email = token.user.email
@@ -100,10 +100,17 @@ class TokenService(object):
 		generate new pair of access and refresh tokens
 		"""
 		exp = time_slice()
+		
+		try:
+			fullname = User.objects.get(pk=user_id).full_name()
+		except ObjectDoesNotExist:
+			fullname = ''
+			
 		payload = {
 			'random': random.randint(1, 1000000),
 			'user_id': user_id,
-			'exp': exp
+			'exp': exp,
+			'fullname': fullname
 		}
 		access_token = jwt.encode(payload, 'access_secret', algorithm='HS256').decode('utf-8')
 		
@@ -144,24 +151,25 @@ class TokenService(object):
 			grant_type = grant_type
 			
 		token = None
-		
+
 		if not TokenService.check_grant_type(grant_type):
 			return False
-		
+
 		# return access token by authorization code
 		if grant_type == 'authorization_code':
 			# return old token if exist and valid or new token if doesn't exist
 			try:
-				token = Token.objects.get(user_id=self.request.user.id, revoked=False,	valid_until__gt=datetime.now())
+				token = Token.objects.get(user_id=self.request.user.id, revoked=False, valid_until__gt=datetime.now())
 			except ObjectDoesNotExist:
 				token = TokenService.make_new_token(self.request.user.id)
 			except MultipleObjectsReturned:
-				token = Token.objects.filter(user_id=self.request.user.id, revoked=False, valid_until__gt=datetime.now()).order_by('-id').first()
-		
+				token = Token.objects.filter(user_id=self.request.user.id, revoked=False,
+												valid_until__gt=datetime.now()).order_by('-id').first()
+
 		# make new access token by refresh token
 		if grant_type == 'refresh_token':
 			token = TokenService.check_refresh_token(self.request.POST.get('refresh_token'))
-			
+
 			if not token:
 				return False
 			else:
@@ -169,7 +177,7 @@ class TokenService(object):
 				token.save()
 				
 				token = TokenService.make_new_token(token.user.id)
-		
+
 		return {
 			'access_token': token.access,
 			'refresh_token': token.refresh
